# mlbcolors

Easy access to the official colors of every team in Major League Baseball. Based on [jimniels/teamcolors](https://github.com/jimniels/teamcolors).


### Installation

```bash
$ pip install mlbcolors
```

### Usage

```bash
>>> import mlbcolors
>>> mlbcolors.get("CHC")
['#CC3433', '#0E3386']
```
